@@ -108,8 +108,8 @@ Extras::Extras()
 	_idToFileMap(0) // initialized in getIdToFileMap()
 {
 	_menu = new TDEPopupMenu(0, "TDEPopupMenu::_menu");
-	connect(_menu, SIGNAL(aboutToShow()), SLOT(slotShowMenu()));
-	connect(_menu, SIGNAL(activated(int)), SLOT(slotActivated(int)));
+	connect(_menu, TQ_SIGNAL(aboutToShow()), TQ_SLOT(slotShowMenu()));
+	connect(_menu, TQ_SIGNAL(activated(int)), TQ_SLOT(slotActivated(int)));
 }
 
 // TODO: 2.0: recent items
@@ -139,7 +139,7 @@ void Extras::buildMenu(TDEPopupMenu *parentMenu, const TQString &subdir)
 		if (fi.isDir())
 		{
 			TDEPopupMenu *submenu = new TDEPopupMenu(parentMenu, "TDEPopupMenu::submenu");
-			connect(submenu, SIGNAL(activated(int)), SLOT(slotActivated(int)));
+			connect(submenu, TQ_SIGNAL(activated(int)), TQ_SLOT(slotActivated(int)));
 
 			KDesktopFile *desktopFile = new KDesktopFile(path + "/.directory", true);
 			if (desktopFile->getConfigState() != TDEConfigBase::NoAccess)
