@@ -99,7 +99,7 @@ Lockout::Lockout(const TQString& configFile, TQWidget *parent)
 	button->setPopupDelay(100);
 	button->setMinimumSize(button->pixmap()->size());
 	button->setSizePolicy(TQSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding));
-	connect(button, SIGNAL(clicked()), this, SLOT(slotShowKShutDown()));
+	connect(button, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotShowKShutDown()));
 
 	button->setPopup(pm_actions);
 	layout->addWidget(button);
@@ -111,7 +111,7 @@ Lockout::Lockout(const TQString& configFile, TQWidget *parent)
 */
 	if (!kapp->dcopClient()->isAttached())
 		kapp->dcopClient()->attach();
-	connect(kapp, SIGNAL(iconChanged(int)), SLOT(slotIconChanged()));
+	connect(kapp, TQ_SIGNAL(iconChanged(int)), TQ_SLOT(slotIconChanged()));
 
 	TQToolTip::add(
 		this,
@@ -163,25 +163,25 @@ void Lockout::initActions() {
 
 	_lockScreenAction = new TDEAction(
 		i18n("Lock Screen"), "system-lock-screen", TDEShortcut(),
-		this, SLOT(slotLockScreen()),
+		this, TQ_SLOT(slotLockScreen()),
 		ac_shutDown, "kshutdown_lockscreen"
 	);
 
 	_logoutAction = new TDEAction(
 		i18n("End Current Session"), "edit-undo", TDEShortcut(),
-		this, SLOT(slotLogout()),
+		this, TQ_SLOT(slotLogout()),
 		ac_shutDown, "kshutdown_logout"
 	);
 
 	_rebootAction = new TDEAction(
 		i18n("Restart Computer"), "reload", TDEShortcut(),
-		this, SLOT(slotReboot()),
+		this, TQ_SLOT(slotReboot()),
 		ac_shutDown, "kshutdown_reboot"
 	);
 
 	_shutDownAction = new TDEAction(
 		i18n("Turn Off Computer"), "system-log-out", TDEShortcut(),
-		this, SLOT(slotShutDown()),
+		this, TQ_SLOT(slotShutDown()),
 		ac_shutDown, "kshutdown_shutdown"
 	);
 
@@ -189,7 +189,7 @@ void Lockout::initActions() {
 
 	_configureKShutDownAction = new TDEAction(
 		i18n("&Configure KShutDown..."), "configure", TDEShortcut(),
-		this, SLOT(slotConfigureKShutDown()),
+		this, TQ_SLOT(slotConfigureKShutDown()),
 		ac_shutDown, "options_configure"
 	);
 }
